@@ -14,7 +14,7 @@ use FindBin qw/$Bin/;
 use Path::Tiny;
 use base qw/Exporter/;
 
-our $VERSION = 0.7;
+our $VERSION = 0.8;
 our ($name)  = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our $tmux_conf    = path("$ENV{HOME}", '.tmux.conf');
 our $tmux_layout  = path("$ENV{HOME}", '.tmux', 'layout');
@@ -33,6 +33,7 @@ sub run {
         'save|s',
         'auto|auto-complete',
         'current=s',
+        'test|t!',
         'verbose|v+',
         'man',
         'help',
@@ -148,7 +149,7 @@ sub process_config {
 
         if ($option{curdir}) {
             delete $option->{curdir};
-            $option->{chdir} = dir('.')->absolute . '';
+            $option->{chdir} = path('.')->realpath . '';
         }
 
         # save the config to YAML
@@ -208,7 +209,7 @@ App::Devmode2 - A tmux session loading tool
 
 =head1 VERSION
 
-This documentation refers to App::Devmode2 version 0.7
+This documentation refers to App::Devmode2 version 0.8
 
 =head1 SYNOPSIS
 
@@ -224,6 +225,7 @@ This documentation refers to App::Devmode2 version 0.7
    -C --curdir  Saves the current director as the directory to change to
                 when next loaded. (implies --save)
 
+   -t --test    Don't run any external command (eg tmux)
    -v --verbose Show more verbose output
       --man     Show full help documentation
       --help    Show this
